AI-Speaker
=================================================================================

Open source home automation that puts local control and privacy first.

Based on  https://home-assistant.io
